@@ -122,8 +122,13 @@ impl Git {
             file::mkdirp(parent)?;
         }
         if SETTINGS.libgit2 || SETTINGS.gix {
+            debug!("Use libgit2 or gix");
             let mut prepare_clone = gix::prepare_clone(url, &self.dir)?;
 
+            if let Some(branch) = &options.branch {
+                prepare_clone = prepare_clone.with_ref_name(Some(branch))?;
+            }
+
             let (mut prepare_checkout, _) = prepare_clone
                 .fetch_then_checkout(gix::progress::Discard, &gix::interrupt::IS_INTERRUPTED)?;
 
